==> lapisworks-1.5.6.8-sources.jar: com/luxof/lapisworks/mixinsupport/LapisworksInterface.java <==
package com.luxof.lapisworks.mixinsupport;

import java.util.List;
import net.minecraft.class_1320;
import net.minecraft.class_5131;

public interface LapisworksInterface {
    public class AllEnchantments {
        public static final int fireyFists = 0;
        public static final int lightningBending = 1;
        public static final int fallDmgRes = 2;
        public static final int longBreath = 3;
        public static final int fireResist = 4;
    }

    double getAmountOfAttrJuicedUpByAmel(class_1320 attribute);
    void setAmountOfAttrJuicedUpByAmel(class_1320 attribute, double value);
    void setAllJuicedUpAttrsToZero();
    
    class_5131 getLapisworksAttributes();
    void setLapisworksAttributes(class_5131 attributes);

	/** expands list up to index if the index is out of bounds, filling the empty spots with 0. */
    int getEnchant(int whatEnchant);
	/** expands list blah blah like getEnchant(). */
    void setEnchantmentLevel(int whatEnchant, int level);
    /** expands list blah blah like getEnchant(). */
    void incrementEnchant(int whatEnchant);
    /** expands list blah blah like getEnchant(). */
    void incrementEnchant(int whatEnchant, int amount);
    /** expands list blah blah like getEnchant(). */
    void decrementEnchant(int whatEnchant);
    /** expands list blah blah like getEnchant(). */
    void decrementEnchant(int whatEnchant, int amount);
	/** resulting list is not mutable. */
    List<Integer> getEnchantments();
	/** this is for nbt stuff. */
    void setEnchantments(int[] levels);
    void setAllEnchantsToZero();
}

==> lapisworks-1.5.7-sources.jar: com/luxof/lapisworks/mixinsupport/LapisworksInterface.java <==
package com.luxof.lapisworks.mixinsupport;

import java.util.List;
import net.minecraft.class_1320;
import net.minecraft.class_3222;
import net.minecraft.class_5131;

public interface LapisworksInterface {
    public class AllEnchantments {
        public static final int fireyFists = 0;
        public static final int lightningBending = 1;
        public static final int fallDmgRes = 2;
        public static final int longBreath = 3;
        public static final int fireResist = 4;
    }

    /** has support for player reach and attack range for convenience. */
    double getAmountOfAttrJuicedUpByAmel(class_1320 attribute);
    /** does not have support for player reach and attack range because wtf entity attrs. */
    void setAmountOfAttrJuicedUpByAmel(class_1320 attribute, double value);
    void setAllJuicedUpAttrsToZero();
    
    class_5131 getLapisworksAttributes();
    void setLapisworksAttributes(class_5131 attributes);

	/** expands list up to index if the index is out of bounds, filling the empty spots with 0. */
    int getEnchant(int whatEnchant);
	/** expands list blah blah like getEnchant(). */
    void setEnchantmentLevel(int whatEnchant, int level);
    /** expands list blah blah like getEnchant(). */
    void incrementEnchant(int whatEnchant);
    /** expands list blah blah like getEnchant(). */
    void incrementEnchant(int whatEnchant, int amount);
    /** expands list blah blah like getEnchant(). */
    void decrementEnchant(int whatEnchant);
    /** expands list blah blah like getEnchant(). */
    void decrementEnchant(int whatEnchant, int amount);
	/** resulting list is not mutable. */
    List<Integer> getEnchantments();
    /** this is for some copying stuff. */
    int[] getEnchantmentsArray();
	/** this is for nbt stuff. */
    void setEnchantments(int[] levels);
    void setAllEnchantsToZero();

    void copyCrossDeath(class_3222 old);
    void copyCrossDimensional(class_3222 old);
}
